@@ -2,21 +2,21 @@
 
 from __future__ import annotations
 
+import typing
+import warnings
 from collections.abc import Sequence
 from copy import deepcopy
-import warnings
-import typing
 
 from packaging.version import Version
 
 from .exceptions import (
     APISpecError,
-    PluginMethodNotImplementedError,
     DuplicateComponentNameError,
     DuplicateParameterError,
     InvalidParameterError,
+    PluginMethodNotImplementedError,
 )
-from .utils import deepupdate, COMPONENT_SUBSECTIONS, build_reference
+from .utils import COMPONENT_SUBSECTIONS, build_reference, deepupdate
 
 if typing.TYPE_CHECKING:
     from .plugin import BasePlugin
@@ -343,6 +343,9 @@ class Components:
     def _resolve_refs_in_parameter_or_header(self, parameter_or_header) -> None:
         self._resolve_schema(parameter_or_header)
         self._resolve_examples(parameter_or_header)
+        # parameter content is OpenAPI v3+
+        for media_type in parameter_or_header.get("content", {}).values():
+            self._resolve_schema(media_type)
 
     def _resolve_refs_in_request_body(self, request_body) -> None:
         # requestBody is OpenAPI v3+
@@ -370,6 +373,11 @@ class Components:
                 self._resolve_refs_in_parameter_or_header(parameter)
                 parameters.append(parameter)
             operation["parameters"] = parameters
+        if "callbacks" in operation:
+            for callback in operation["callbacks"].values():
+                if isinstance(callback, dict):
+                    for path in callback.values():
+                        self.resolve_refs_in_path(path)
         if "requestBody" in operation:
             self._resolve_refs_in_request_body(operation["requestBody"])
         if "responses" in operation:
@@ -556,7 +564,6 @@ class APISpec:
         """
         seen = set()
         for parameter in [p for p in parameters if isinstance(p, dict)]:
-
             # check missing name / location
             missing_attrs = [attr for attr in ("name", "in") if attr not in parameter]
             if missing_attrs:
@@ -615,6 +622,10 @@ class APISpec:
                         code = int(code)  # handles IntEnums like http.HTTPStatus
                     except (TypeError, ValueError):
                         if self.openapi_version.major < 3 and code != "default":
-                            warnings.warn("Non-integer code not allowed in OpenAPI < 3")
+                            warnings.warn(
+                                "Non-integer code not allowed in OpenAPI < 3",
+                                UserWarning,
+                                stacklevel=2,
+                            )
                     responses[str(code)] = response
                 operation["responses"] = responses
